@@ -1,4 +1,3 @@
-import dataclasses
 import ntpath
 from enum import Enum
 from functools import lru_cache
@@ -7,20 +6,10 @@ from typing import Any, AnyStr, AsyncIterable, Callable, Union
 
 from essentials.json import FriendlyEncoder, dumps as friendly_dumps
 
-from blacksheep import Content, JsonContent, Response, StreamedContent, TextContent
+from blacksheep import Content, JSONContent, Response, StreamedContent, TextContent
 from blacksheep.common.files.asyncfs import FilesHandler
 
 
-class FriendlyEncoderExtended(FriendlyEncoder):
-    def default(self, obj):
-        try:
-            return super().default(obj)
-        except TypeError:
-            if dataclasses.is_dataclass(obj):
-                return dataclasses.asdict(obj)
-            raise
-
-
 MessageType = Any
 
 
@@ -38,11 +27,11 @@ def _ensure_bytes(value: AnyStr) -> bytes:
 
 
 def _json_serialize(obj) -> str:
-    return friendly_dumps(obj, cls=FriendlyEncoderExtended, separators=(",", ":"))
+    return friendly_dumps(obj, cls=FriendlyEncoder, separators=(",", ":"))
 
 
-def _json_content(obj) -> JsonContent:
-    return JsonContent(obj, _json_serialize)
+def _json_content(obj) -> JSONContent:
+    return JSONContent(obj, _json_serialize)
 
 
 def _optional_content(message: Any = None) -> Content:
@@ -201,9 +190,7 @@ def json(data: Any, status: int = 200, dumps=friendly_dumps) -> Response:
         None,
         Content(
             b"application/json",
-            dumps(data, cls=FriendlyEncoderExtended, separators=(",", ":")).encode(
-                "utf8"
-            ),
+            dumps(data, cls=FriendlyEncoder, separators=(",", ":")).encode("utf8"),
         ),
     )
 
@@ -220,7 +207,7 @@ def pretty_json(
         None,
         Content(
             b"application/json",
-            dumps(data, cls=FriendlyEncoderExtended, indent=indent).encode("utf8"),
+            dumps(data, cls=FriendlyEncoder, indent=indent).encode("utf8"),
         ),
     )
 
